package org.jboss.virtual.plugins.context.zip;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Date;
import java.util.Enumeration;
import java.util.List;
import java.util.zip.ZipEntry;

public class Test1 {
    
    public static void main(String[] args) throws IOException, InterruptedException {
        
        if (args.length < 1) {
            System.out.println("Please use directory of jars as argument!");
            System.exit(1);
        }
        File dir = new File(args[0]);
        if (!dir.exists()) {
            System.out.println("Directory " + args[0] + " doesn't exist!");
            System.exit(1);
        }
        
        System.out.println("Start processing directory " + dir);
        File[] jars = dir.listFiles();
        for (File jar: jars) {
            process(jar);
            System.out.println("Sleep 1 seconds, have a break.");
            System.out.println();
            System.out.println();
            Thread.sleep(1 * 1000);
        }
        
        System.out.println("Now: " + new Date());
        System.out.println("Force GC");
        System.gc();
        System.out.println("Force Finalization");
        System.runFinalization();
        System.out.println("Sleep 1 min, let GC and Finalization finish");
        Thread.sleep(60 * 1000);
    }
    
    private static void process(File jar) throws IOException {
        if (jar.isDirectory()) {
            System.out.println("Skip directory " + jar.getName());
            return;
        }
        System.out.println("Processing jar " + jar.getName());
        ZipFileWrapper zfw = new ZipFileWrapper(jar, false, true);
        Enumeration<? extends ZipEntry> entries = zfw.entries();
        List<ZipEntry> entryList = new ArrayList<ZipEntry>();
        while(entries.hasMoreElements()) {
            ZipEntry entry = entries.nextElement();
            entryList.add(entry);
        }
        
        for (ZipEntry entry: entryList) {
            if (entry.isDirectory()) {
                System.out.println("Skip directory " + entry.getName());
                continue;
            } else {
                System.out.println("Processing " + entry.getName());
            }
            
            InputStream stream = null;
            try {
                stream = zfw.openStream(entry);
                int value = 0;
                while ((value = stream.read()) >= 0) {
                    //do nothing
                }
            } catch (Exception e) {
                System.out.println("Error " + entry.getName());
            } finally {
                if (stream != null) {
                    stream.close();
                }
            }
        }
    }

}
